@@ -3,8 +3,7 @@
 """Date module
 """
 
-from numpy import sin, radians
-from collections import namedtuple
+from numpy import sin, radians, ceil
 from datetime import datetime, timedelta, date
 
 from ..errors import DateError, UnknownScaleError
@@ -18,7 +17,7 @@ class Timescale(Node):
     """Definition of a time scale and its interactions with others"""
 
     def __repr__(self):  # pragma: no cover
-        return "<Scale '%s'>" % self.name
+        return f"<Scale '{self.name}'>"
 
     def __str__(self):
         return self.name
@@ -62,15 +61,15 @@ class Timescale(Node):
             one = one.name.lower()
             two = two.name.lower()
             # find the operation
-            oper = "_scale_{}_minus_{}".format(two, one)
+            oper = f"_scale_{two}_minus_{one}"
             # find the reverse operation
-            roper = "_scale_{}_minus_{}".format(one, two)
+            roper = f"_scale_{one}_minus_{two}"
             if hasattr(self, oper):
                 delta += getattr(self, oper)(mjd, eop)
             elif hasattr(self, roper):
                 delta -= getattr(self, roper)(mjd, eop)
             else:  # pragma: no cover
-                raise DateError("Unknown convertion {} => {}".format(one, two))
+                raise DateError(f"Unknown convertion {one} => {two}")
 
         return delta
 
@@ -176,7 +175,7 @@ class Date:
                     d = int(arg)
                     s = (arg - d) * 86400
             else:
-                raise TypeError("Unknown type '{}'".format(type(arg)))
+                raise TypeError(f"Unknown type '{type(arg)}'")
         elif len(args) == 2 and (
             isinstance(args[0], int) and isinstance(args[1], (int, float))
         ):
@@ -189,7 +188,7 @@ class Date:
             d, s = self._convert_dt(dt)
         else:
             raise TypeError(
-                "Unknown type sequence {}".format(", ".join(str(type(x)) for x in args))
+                f"Unknown type sequence {', '.join(str(type(x)) for x in args)}"
             )
 
         mjd = d + s / 86400.0
@@ -242,7 +241,7 @@ class Date:
         if isinstance(other, timedelta):
             days, sec = divmod(other.total_seconds() + self.s, 86400)
         else:
-            raise TypeError("Unknown operation with {}".format(type(other)))
+            raise TypeError(f"Unknown operation with {type(other)}")
 
         return self.__class__(self.d + int(days), sec, scale=self.scale)
 
@@ -254,7 +253,7 @@ class Date:
         elif isinstance(other, Date):
             return self._datetime - other._datetime
         else:
-            raise TypeError("Unknown operation with {}".format(type(other)))
+            raise TypeError(f"Unknown operation with {type(other)}")
 
         return self.__add__(other)
 
@@ -274,11 +273,11 @@ class Date:
         return self._mjd == other._mjd
 
     def __repr__(self):  # pragma: no cover
-        return "<{} '{}'>".format(self.__class__.__name__, self)
+        return f"<{self.__class__.__name__} '{self}'>"
 
     def __str__(self):  # pragma: no cover
         if "str" not in self._cache.keys():
-            self._cache["str"] = "{} {}".format(self.datetime.isoformat(), self.scale)
+            self._cache["str"] = f"{self.datetime.isoformat()} {self.scale}"
         return self._cache["str"]
 
     def __format__(self, fmt):  # pragma: no cover
@@ -362,7 +361,7 @@ class Date:
         Args:
             new_scale (str)
         Return:
-            Date
+            Date: new Date object representing the same instant, with a different timescale
         """
         offset = self.scale.offset(self._mjd, new_scale, self.eop)
         result = self.datetime + timedelta(seconds=offset)
@@ -411,11 +410,82 @@ class Date:
         return self.d + self.s / 86400.0
 
     @classmethod
-    def range(cls, start=None, stop=None, step=None, inclusive=False):
-        return DateRange(start, stop, step, inclusive)
+    def range(cls, *args, **kwargs):
+        """See :py:class:`DateRange` for arguments and documentation"""
+        return DateRange(*args, **kwargs)
+
+
+class DateRange:
+    """Object representing a range of Date objects
+
+    Allow for manipulation of the range before any computation.
+    It has a lenght, can be used as an iterable, and be checked against
+    for membership.
+
+    Example:
+
+        >>> start = Date(2021, 2, 9, 23, 35, 58)
+        >>> stop = timedelta(hours=1, minutes=1)
+        >>> step = timedelta(minutes=15)
+        >>> r = Date.range(start, stop, step)
+        >>> len(r)
+        5
+        >>> for d in r:  # iterable
+        ...     print(d)
+        ...
+        2021-02-09T23:35:58 UTC
+        2021-02-09T23:50:58 UTC
+        2021-02-10T00:05:58 UTC
+        2021-02-10T00:20:58 UTC
+        2021-02-10T00:35:58 UTC
+        >>> Date(2021, 2, 9, 23, 45) in r  # membership test
+        True
+    """
+
+    def __init__(self, start, stop, step, *, inclusive=False):
+        """
+
+        Args:
+            start (Date): Begining of the range
+            stop (Date or datetime.timedelta): End of the range
+            step (timedelta): step size
+            inclusive (bool): If ``False``, the stopping date is not included.
+                This is the same behavior as the built-in :py:func:`range`.
+        """
+
+        # Convert stop from timedelta to Date object
+        if isinstance(stop, timedelta):
+            stop = start + stop
+
+        if not step:
+            raise ValueError("Null step")
+
+        if self._sign((stop - start)) != self._sign(step):
+            raise ValueError("start/stop order not coherent with step")
+
+        self.start = start
+        """Date : Begining of the range"""
+
+        self.stop = stop
+        """Date : End of the range"""
+
+        self.step = step
+        """timedelta : Step size, can be positive or negative"""
+
+        self.inclusive = inclusive
+        """bool : inclusive flag"""
+
+    @property
+    def dur(self):
+        """timedelta : duration of the DateRange object"""
+        return self.stop - self.start
 
     @classmethod
-    def _range(cls, start=None, stop=None, step=None, inclusive=False):
+    def _sign(cls, x):
+        """Inner function for determining the sign of a float"""
+        return (-1, 1)[x.total_seconds() >= 0]
+
+    def __iter__(self):
         """Generator of a date range
 
         Args:
@@ -429,74 +499,30 @@ class Date:
             Date:
         """
 
-        def sign(x):
-            """Inner function for determining the sign of a float"""
-            return (-1, 1)[x >= 0]
+        date = self.start
 
-        if not step:
-            raise ValueError("Null step")
-
-        # Convert stop from timedelta to Date object
-        if isinstance(stop, timedelta):
-            stop = start + stop
-
-        if sign((stop - start).total_seconds()) != sign(step.total_seconds()):
-            raise ValueError("start/stop order not coherent with step")
-
-        date = start
-
-        if step.total_seconds() > 0:
-            oper = "__le__" if inclusive else "__lt__"
+        if self.step.total_seconds() > 0:
+            oper = "__le__" if self.inclusive else "__lt__"
         else:
-            oper = "__ge__" if inclusive else "__gt__"
+            oper = "__ge__" if self.inclusive else "__gt__"
 
-        while getattr(date, oper)(stop):
+        while getattr(date, oper)(self.stop):
             yield date
-            date += step
-
-
-class DateRange:
-    """Object representing a Date.range call
-
-    Allow for manipulation of the range before any compytation
-    """
-
-    _descriptor = namedtuple("range_descriptor", "start stop step inclusive")
-
-    def __init__(self, start, stop, step, inclusive):
-        """
-
-        Args:
-            start (Date):
-            stop (Date or datetime.timedelta):
-            step (timedelta):
-            inclusive (bool): If ``False``, the stopping date is not included.
-                This is the same behavior as the built-in :py:func:`range`.
-        """
-
-        if isinstance(stop, timedelta):
-            stop = start + stop
-
-        self._range = self._descriptor(start, stop, step, inclusive)
-
-    def __iter__(self):
-        for d in Date._range(*self._range):
-            yield d
+            date += self.step
 
     def __contains__(self, date):
-        return self.start <= date <= self.stop
+        if self.inclusive:
+            return self.start <= date <= self.stop
+        else:
+            return self.start <= date < self.stop
 
-    @property
-    def start(self):
-        return self._range.start
+    def __len__(self):
+        if self.inclusive and self.dur % self.step == timedelta(0):
+            plus = 1
+        else:
+            plus = 0
 
-    @property
-    def stop(self):
-        return self._range.stop
-
-    @property
-    def step(self):
-        return self._range.step
+        return int(ceil(self.dur / self.step)) + plus
 
 
 # This part is here to allow matplotlib to display Date objects directly
